summaryrefslogtreecommitdiff
path: root/dumpcap.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-05 12:15:27 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-05 19:16:22 +0000
commit357cfd3b035d1ba6438e82cc1cbec105874206b6 (patch)
tree58a77b4dc8e1192db6278716b320bf42a18ded8f /dumpcap.c
parent1f94d34f43055ea47fc9426e1720bdb4b7397dd9 (diff)
downloadwireshark-357cfd3b035d1ba6438e82cc1cbec105874206b6.tar.gz
A bunch of "{Mac} OS X" -> "macOS" changes.
Avoid anachronisms, however; there was no "macOS 10.0" or even "OS X 10.0", for example. It was "Mac OS X" until 10.8 (although 10.7 was sometimes called "OS X" and sometimes called "Mac OS X"), and it was "OS X" from 10.8 to 10.11. Change-Id: Ie4a848997dcc6c45c2245c1fb84ec526032375c3 Reviewed-on: https://code.wireshark.org/review/20933 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'dumpcap.c')
-rw-r--r--dumpcap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/dumpcap.c b/dumpcap.c
index e21e80be85..4cbee02a8a 100644
--- a/dumpcap.c
+++ b/dumpcap.c
@@ -371,7 +371,7 @@ static gboolean need_timeout_workaround;
/*
* Timeout, in microseconds, for reads from the stream of captured packets
* from a pipe. Pipes don't have the same problem that BPF devices do
* in OS X 10.6, 10.6.1, 10.6.3, and 10.6.4, so we always use a timeout
* of 250ms, i.e. the same value as CAP_READ_TIMEOUT when not on one
* of the offending versions of Snow Leopard.
*
@@ -3368,7 +3368,7 @@ capture_loop_start(capture_options *capture_opts, gboolean *stats_known, struct
(At least you will if g_strerror() doesn't show a local translation
of the error.)
- On FreeBSD and OS X, if a network adapter disappears while
+ On FreeBSD and macOS, if a network adapter disappears while
you're capturing on it, you'll get a "read: Device not configured"
error (ENXIO). (See previous parenthetical note.)
@@ -3877,7 +3877,7 @@ main(int argc, char *argv[])
*/
if (uname(&osinfo) == 0) {
/*
* Mac OS X 10.x uses Darwin {x+4}.0.0. Mac OS X 10.x.y uses Darwin
* {x+4}.y.0 (except that 10.6.1 appears to have a uname version
* number of 10.0.0, not 10.1.0 - go figure).
*/
@@ -371,7 +371,7 @@ static gboolean need_timeout_workaround;
* Timeout, in microseconds, for reads from the stream of captured packets
* from a pipe. Pipes don't have the same problem that BPF devices do
- * in OS X 10.6, 10.6.1, 10.6.3, and 10.6.4, so we always use a timeout
+ * in Mac OS X 10.6, 10.6.1, 10.6.3, and 10.6.4, so we always use a timeout
* of 250ms, i.e. the same value as CAP_READ_TIMEOUT when not on one
* of the offending versions of Snow Leopard.
@@ -3877,7 +3877,7 @@ main(int argc, char *argv[])
if (uname(&osinfo) == 0) {
/*
- * Mac OS X 10.x uses Darwin {x+4}.0.0. Mac OS X 10.x.y uses Darwin
+ * {Mac} OS X/macOS 10.x uses Darwin {x+4}.0.0; 10.x.y uses Darwin
* {x+4}.y.0 (except that 10.6.1 appears to have a uname version
* number of 10.0.0, not 10.1.0 - go figure).